==> aliyun-java-sdk-ecs-2.2.0-sources.jar: com/aliyuncs/ecs/model/v20140526/ModifyIntranetBandwidthKbRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;

/**
 * @author auto create
 * @version 
 */
public class ModifyIntranetBandwidthKbRequest extends RpcAcsRequest<ModifyIntranetBandwidthKbResponse> {
	
	public ModifyIntranetBandwidthKbRequest() {
		super("Ecs", "2014-05-26", "ModifyIntranetBandwidthKb");
	}

	private Long ownerId;

	private String resourceOwnerAccount;

	private Long resourceOwnerId;

	private String instanceId;

	private Integer intranetMaxBandwidthIn;

	private Integer intranetMaxBandwidthOut;

	private String ownerAccount;

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		putQueryParameter("OwnerId", ownerId);
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		putQueryParameter("ResourceOwnerId", resourceOwnerId);
	}

	public String getInstanceId() {
		return this.instanceId;
	}

	public void setInstanceId(String instanceId) {
		this.instanceId = instanceId;
		putQueryParameter("InstanceId", instanceId);
	}

	public Integer getIntranetMaxBandwidthIn() {
		return this.intranetMaxBandwidthIn;
	}

	public void setIntranetMaxBandwidthIn(Integer intranetMaxBandwidthIn) {
		this.intranetMaxBandwidthIn = intranetMaxBandwidthIn;
		putQueryParameter("IntranetMaxBandwidthIn", intranetMaxBandwidthIn);
	}

	public Integer getIntranetMaxBandwidthOut() {
		return this.intranetMaxBandwidthOut;
	}

	public void setIntranetMaxBandwidthOut(Integer intranetMaxBandwidthOut) {
		this.intranetMaxBandwidthOut = intranetMaxBandwidthOut;
		putQueryParameter("IntranetMaxBandwidthOut", intranetMaxBandwidthOut);
	}

	public String getOwnerAccount() {
		return this.ownerAccount;
	}

	public void setOwnerAccount(String ownerAccount) {
		this.ownerAccount = ownerAccount;
		putQueryParameter("OwnerAccount", ownerAccount);
	}

	@Override
	public Class<ModifyIntranetBandwidthKbResponse> getResponseClass() {
		return ModifyIntranetBandwidthKbResponse.class;
	}

}

==> aliyun-java-sdk-ecs-3.2.0-sources.jar: com/aliyuncs/ecs/model/v20140526/ModifyIntranetBandwidthKbRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;

/**
 * @author auto create
 * @version 
 */
public class ModifyIntranetBandwidthKbRequest extends RpcAcsRequest<ModifyIntranetBandwidthKbResponse> {
	
	public ModifyIntranetBandwidthKbRequest() {
		super("Ecs", "2014-05-26", "ModifyIntranetBandwidthKb", "ecs");
	}

	private Long ownerId;

	private String resourceOwnerAccount;

	private Long resourceOwnerId;

	private String instanceId;

	private Integer intranetMaxBandwidthIn;

	private Integer intranetMaxBandwidthOut;

	private String ownerAccount;

	public Long getOwnerId() {
		return this.ownerId;
	}

	public void setOwnerId(Long ownerId) {
		this.ownerId = ownerId;
		putQueryParameter("OwnerId", ownerId);
	}

	public String getResourceOwnerAccount() {
		return this.resourceOwnerAccount;
	}

	public void setResourceOwnerAccount(String resourceOwnerAccount) {
		this.resourceOwnerAccount = resourceOwnerAccount;
		putQueryParameter("ResourceOwnerAccount", resourceOwnerAccount);
	}

	public Long getResourceOwnerId() {
		return this.resourceOwnerId;
	}

	public void setResourceOwnerId(Long resourceOwnerId) {
		this.resourceOwnerId = resourceOwnerId;
		putQueryParameter("ResourceOwnerId", resourceOwnerId);
	}

	public String getInstanceId() {
		return this.instanceId;
	}

	public void setInstanceId(String instanceId) {
		this.instanceId = instanceId;
		putQueryParameter("InstanceId", instanceId);
	}

	public Integer getIntranetMaxBandwidthIn() {
		return this.intranetMaxBandwidthIn;
	}

	public void setIntranetMaxBandwidthIn(Integer intranetMaxBandwidthIn) {
		this.intranetMaxBandwidthIn = intranetMaxBandwidthIn;
		putQueryParameter("IntranetMaxBandwidthIn", intranetMaxBandwidthIn);
	}

	public Integer getIntranetMaxBandwidthOut() {
		return this.intranetMaxBandwidthOut;
	}

	public void setIntranetMaxBandwidthOut(Integer intranetMaxBandwidthOut) {
		this.intranetMaxBandwidthOut = intranetMaxBandwidthOut;
		putQueryParameter("IntranetMaxBandwidthOut", intranetMaxBandwidthOut);
	}

	public String getOwnerAccount() {
		return this.ownerAccount;
	}

	public void setOwnerAccount(String ownerAccount) {
		this.ownerAccount = ownerAccount;
		putQueryParameter("OwnerAccount", ownerAccount);
	}

	@Override
	public Class<ModifyIntranetBandwidthKbResponse> getResponseClass() {
		return ModifyIntranetBandwidthKbResponse.class;
	}

}
